"""Brazil locale data — pt_BR"""

FIRST_NAMES_MALE = [
    "Miguel", "Arthur", "Bernardo", "Heitor", "Davi", "Lorenzo", "Théo", "Pedro", "Gabriel",
    "Enzo", "Matheus", "Lucas", "Rafael", "João", "Gustavo", "Felipe", "Guilherme",
    "Nicolas", "Samuel", "Daniel", "Henrique", "Eduardo", "Leonardo", "Bruno", "Caio",
    "Vinícius", "Diego", "André", "Rodrigo", "Thiago", "Fernando", "Marcelo", "Ricardo",
    "Roberto", "Alexandre", "Carlos", "Paulo", "Francisco", "José", "Antônio", "Marcos",
    "Leandro", "Fábio", "Sérgio", "Renato", "Márcio", "Cláudio", "Luís", "Rogério",
    "Jorge", "Adriano", "Flávio", "Julio", "Luciano", "Renan", "Igor", "Otávio", "Murilo",
    "Cauã", "Luan", "Breno", "Benício", "Vicente", "Emanuel", "Ravi", "Bryan", "Isaac",
    "Anthony", "Pietro", "Henry", "Gael", "Bento", "Noah", "Caleb", "Joaquim", "Raul",
    "Martin", "Ian", "Tomás", "Augusto", "César", "Elias", "Levi", "Nathan", "Yuri",
    "Pablo", "Tales", "Danilo", "Emerson", "Hugo", "Mateus", "Tiago", "Anderson",
    "Cristiano", "Edson", "Neymar", "Ronaldo", "Valdir", "Wanderley", "Wilson", "Ivan",
    "Nelson", "Osvaldo",
]

FIRST_NAMES_FEMALE = [
    "Alice", "Sophia", "Helena", "Valentina", "Laura", "Isabella", "Manuela", "Júlia",
    "Heloísa", "Luísa", "Maria", "Lorena", "Lívia", "Giovanna", "Beatriz", "Gabriela",
    "Letícia", "Isadora", "Mariana", "Ana", "Camila", "Rafaela", "Fernanda", "Carolina",
    "Juliana", "Amanda", "Bruna", "Larissa", "Tatiana", "Patrícia", "Vanessa", "Adriana",
    "Renata", "Luciana", "Simone", "Cristiane", "Cláudia", "Rosana", "Sandra", "Mônica",
    "Márcia", "Denise", "Sônia", "Vera", "Regina", "Célia", "Eliane", "Lúcia", "Tereza",
    "Francisca", "Rita", "Rosa", "Marta", "Débora", "Priscila", "Aline", "Natália",
    "Viviane", "Daniela", "Carla", "Bianca", "Marina", "Yasmin", "Lara", "Cecília",
    "Clara", "Emanuelly", "Eloá", "Antonella", "Maya", "Agatha", "Rebeca", "Sophie",
    "Alícia", "Luna", "Melissa", "Catarina", "Stella", "Jade", "Olívia", "Aurora",
    "Isis", "Esther", "Elisa", "Liz", "Pietra", "Milena", "Raquel", "Vitória",
    "Alessandra", "Flávia", "Thaís", "Jéssica", "Fabiana", "Michele", "Andréia",
    "Elisângela", "Joana", "Iara", "Ingrid", "Paloma",
]

LAST_NAMES = [
    "Silva", "Santos", "Oliveira", "Souza", "Rodrigues", "Ferreira", "Alves", "Pereira",
    "Lima", "Gomes", "Costa", "Ribeiro", "Martins", "Carvalho", "Araújo", "Melo",
    "Barbosa", "Rocha", "Cardoso", "Nascimento", "Moreira", "Nunes", "Marques", "Machado",
    "Mendes", "Freitas", "Monteiro", "Cavalcanti", "Dias", "Castro", "Campos", "Teixeira",
    "Moura", "Vieira", "Correia", "Pinto", "Batista", "Soares", "Reis", "Lopes",
    "Miranda", "Duarte", "Ramos", "Fernandes", "Barros", "Farias", "Bezerra", "Amaral",
    "Pires", "Cunha", "Sales", "Sampaio", "Azevedo", "Medeiros", "Siqueira", "Andrade",
    "Borges", "Fonseca", "Peixoto", "Nogueira", "Aguiar", "Brito", "Leal", "Rezende",
    "Coelho", "Xavier", "Alencar", "Lacerda", "Guimarães", "Tavares", "Pacheco", "Viana",
    "Queiroz", "Morais", "Paiva", "Bastos", "Carneiro", "Matos", "Santiago", "Magalhães",
    "Rangel", "Assis", "Dantas", "Silveira", "Braga", "Toledo", "Porto", "Dourado",
    "Figueiredo", "Coutinho", "Moraes", "Simões", "Prado", "Franco", "Barreto", "Vargas",
    "Trindade", "Valente", "Mesquita", "Sena",
]

CITIES = [
    "São Paulo", "Rio de Janeiro", "Brasília", "Salvador", "Fortaleza", "Belo Horizonte",
    "Manaus", "Curitiba", "Recife", "Porto Alegre", "Belém", "Goiânia", "Guarulhos",
    "Campinas", "São Luís", "Maceió", "Duque de Caxias", "Campo Grande", "Natal",
    "Teresina", "São Bernardo do Campo", "João Pessoa", "Osasco", "Jaboatão", "Uberlândia",
    "Contagem", "Sorocaba", "Aracaju", "Feira de Santana", "Cuiabá",
]

STREET_FORMATS = [
    "Rua {name}, {number}", "Avenida {name}, {number}",
    "Travessa {name}, {number}", "Alameda {name}, {number}",
]

POSTAL_CODE_FORMAT = "#####-###"
PHONE_FORMAT = "+55 (##) #####-####"
CURRENCY = "BRL"
CURRENCY_SYMBOL = "R$"

BANKS = [
    "Banco do Brasil", "Itaú Unibanco", "Bradesco", "Caixa Econômica Federal",
    "Santander Brasil", "Nubank", "Inter", "BTG Pactual", "Safra", "Sicoob",
    "Banco Original", "C6 Bank",
]

EMAIL_DOMAINS = ["gmail.com", "hotmail.com", "uol.com.br", "outlook.com", "bol.com.br", "terra.com.br"]
COMPANY_SUFFIXES = ["Ltda.", "S.A.", "ME", "EIRELI", "S/S", "EPP"]
COUNTRY_NAME = "Brasil"
NAME_ORDER = "given_family"
