"""United Kingdom locale data — en_GB"""

FIRST_NAMES_MALE = [
    "Oliver", "George", "Arthur", "Noah", "Muhammad", "Leo", "Oscar", "Harry", "Archie",
    "Jack", "Henry", "Charlie", "Freddie", "Theo", "Thomas", "James", "William", "Edward",
    "Alexander", "Daniel", "Alfie", "Jacob", "Isaac", "Ethan", "Joseph", "Joshua",
    "Sebastian", "Lucas", "Max", "Samuel", "Logan", "Benjamin", "Harrison", "Theodore",
    "Dylan", "Finley", "Adam", "Mason", "Elijah", "Toby", "Reuben", "Jayden", "Liam",
    "Harvey", "Hugo", "Tommy", "Louie", "Jude", "Mohammad", "Ronnie", "Bobby", "Frankie",
    "Stanley", "Teddy", "Albert", "Reggie", "Albie", "Elliot", "Zachary", "Luca",
    "Gabriel", "Connor", "Caleb", "Nathan", "Aaron", "Louis", "Kai", "Blake", "Luke",
    "Riley", "Robert", "Matthew", "Ryan", "Tyler", "Ben", "Callum", "Aiden", "Cameron",
    "Lewis", "Owen", "Declan", "Kyle", "Jamie", "Kieran", "Ross", "Craig", "Scott",
    "Gareth", "Stuart", "Darren", "Lee", "Mark", "Ian", "Paul", "Stephen", "Andrew",
    "Simon", "David", "Michael", "Christopher", "Jonathan", "Peter", "Richard",
]

FIRST_NAMES_FEMALE = [
    "Olivia", "Amelia", "Isla", "Ava", "Mia", "Ivy", "Lily", "Isabella", "Rosie", "Sophia",
    "Grace", "Florence", "Freya", "Emily", "Poppy", "Charlotte", "Eleanor", "Ella",
    "Evelyn", "Daisy", "Sienna", "Matilda", "Willow", "Phoebe", "Ruby", "Sophie",
    "Alice", "Isabelle", "Harper", "Maisie", "Luna", "Aria", "Emilia", "Penelope",
    "Scarlett", "Millie", "Violet", "Layla", "Elsie", "Chloe", "Jessica", "Maya",
    "Bonnie", "Imogen", "Lottie", "Hallie", "Bella", "Zara", "Hannah", "Thea",
    "Esme", "Abigail", "Orla", "Eva", "Georgia", "Eliza", "Holly", "Margot", "Molly",
    "Darcie", "Annabelle", "Erin", "Iris", "Lola", "Maeve", "Robyn", "Heidi", "Eloise",
    "Mabel", "Ayla", "Elizabeth", "Martha", "Jasmine", "Clara", "Arabella", "Darcey",
    "Bethany", "Katherine", "Lucy", "Katie", "Emma", "Leah", "Lauren", "Amy", "Rebecca",
    "Rachel", "Laura", "Sarah", "Jennifer", "Victoria", "Louise", "Gemma", "Kelly",
    "Nicola", "Karen", "Sharon", "Lisa", "Tracy", "Joanne", "Claire", "Helen",
]

LAST_NAMES = [
    "Smith", "Jones", "Williams", "Taylor", "Brown", "Davies", "Wilson", "Evans", "Thomas",
    "Roberts", "Johnson", "Walker", "Wright", "Robinson", "Thompson", "White", "Hughes",
    "Edwards", "Green", "Hall", "Lewis", "Harris", "Clarke", "Patel", "Jackson",
    "Wood", "Turner", "Martin", "Cooper", "Hill", "Ward", "Morris", "Moore", "Clark",
    "Lee", "King", "Baker", "Harrison", "Morgan", "Allen", "James", "Scott", "Phillips",
    "Watson", "Davis", "Parker", "Price", "Bennett", "Young", "Griffiths", "Mitchell",
    "Kelly", "Cook", "Carter", "Richardson", "Bailey", "Collins", "Bell", "Shaw", "Murphy",
    "Miller", "Cox", "Richards", "Khan", "Marshall", "Anderson", "Simpson", "Ellis",
    "Adams", "Singh", "Begum", "Wilkinson", "Foster", "Chapman", "Powell", "Webb",
    "Rogers", "Gray", "Mason", "Ali", "Hunt", "Hussain", "Campbell", "Matthews",
    "Owen", "Palmer", "Holmes", "Mills", "Barnes", "Knight", "Lloyd", "Butler",
    "Russell", "Barker", "Fisher", "Stevens", "Jenkins", "Murray", "Dixon", "Harvey",
]

CITIES = [
    "London", "Manchester", "Birmingham", "Leeds", "Glasgow", "Liverpool", "Bristol",
    "Edinburgh", "Sheffield", "Cardiff", "Nottingham", "Newcastle", "Brighton", "Oxford",
    "Cambridge", "Leicester", "Coventry", "Belfast", "Sunderland", "Wolverhampton",
    "Plymouth", "Southampton", "Reading", "Derby", "Aberdeen", "Swansea", "Exeter",
    "York", "Bath", "Canterbury",
]

STREET_FORMATS = [
    "{number} {name} Street", "{number} {name} Road", "{number} {name} Lane",
    "{number} {name} Close", "{number} {name} Crescent", "{number} {name} Gardens",
    "{number} {name} Terrace", "{number} {name} Mews",
]

POSTAL_CODE_FORMAT = "??# #??"
PHONE_FORMAT = "+44 #### ######"
CURRENCY = "GBP"
CURRENCY_SYMBOL = "£"

BANKS = [
    "Barclays", "HSBC", "Lloyds Banking Group", "NatWest", "Santander UK",
    "Nationwide", "TSB", "Metro Bank", "Monzo", "Starling Bank",
    "Halifax", "Royal Bank of Scotland",
]

EMAIL_DOMAINS = ["gmail.com", "outlook.com", "yahoo.co.uk", "btinternet.com", "sky.com", "hotmail.co.uk"]
COMPANY_SUFFIXES = ["Ltd", "PLC", "LLP", "Group", "& Co.", "Partners", "Holdings"]
COUNTRY_NAME = "United Kingdom"
NAME_ORDER = "given_family"
