"""Nigeria locale data — en_NG"""

FIRST_NAMES_MALE = [
    "Chinedu", "Oluwaseun", "Emeka", "Tunde", "Ifeanyi", "Obinna", "Adebayo", "Chibueze",
    "Ayomide", "Olumide", "Yusuf", "Ibrahim", "Chukwuma", "Damilare", "Ebuka", "Kelechi",
    "Tochukwu", "Abiodun", "Femi", "Uche", "Olamide", "Babajide", "Chinonso", "Adekunle",
    "Ikechukwu", "Nnamdi", "Olalekan", "Temitope", "Gbenga", "Segun", "Musa", "Abdullahi",
    "Aliyu", "Aminu", "Bashir", "Danjuma", "Garba", "Hamza", "Idris", "Jibril",
    "Kabiru", "Lawal", "Murtala", "Nuhu", "Suleiman", "Usman", "Yakubu", "Abubakar",
    "Chidi", "Chijioke", "Chuka", "Ekene", "Ifeanyichukwu", "Jideofor", "Kenechukwu",
    "Lotachukwu", "Munachi", "Nnaemeka", "Obichukwu", "Odinaka", "Onyeka", "Somtochukwu",
    "Tobechukwu", "Uchechukwu", "Chukwuemeka", "Adewale", "Akintunde", "Bamidele",
    "Boluwatife", "Dapo", "Folarin", "Kolawole", "Oluwadamilola", "Oluwatobi",
    "Oluwatosin", "Rotimi", "Saheed", "Taiwo", "Kehinde", "Wale", "Ayo", "Kunle",
    "Niyi", "Sola", "Dele", "Lanre", "Lekan", "Toyin", "Jide", "Tayo", "Bode",
    "Kayode", "Adeniyi", "Olayinka", "Olufemi", "Olusegun", "Olusola", "Oluwaferanmi",
    "Adedayo", "Goodluck", "Sunday",
]

FIRST_NAMES_FEMALE = [
    "Chioma", "Ngozi", "Amara", "Oluwabunmi", "Funke", "Adaeze", "Yetunde", "Ifeoma",
    "Blessing", "Aisha", "Chiamaka", "Nneka", "Halima", "Titilayo", "Zainab", "Kemi",
    "Nkechi", "Folake", "Ada", "Ogechi", "Onyinyechi", "Bukola", "Nkem", "Adaugo",
    "Ebere", "Uchenna", "Chinwe", "Adaora", "Nwanneka", "Oluchi", "Chinelo", "Somkene",
    "Amarachi", "Obiageli", "Njideka", "Oluwatoyin", "Oluwaseun", "Adenike", "Abimbola",
    "Jumoke", "Modupe", "Omolara", "Opeyemi", "Tolulope", "Temilolu", "Boluwatife",
    "Oluwadamilola", "Oluwadarasimi", "Morayo", "Morenike", "Yewande", "Eniola",
    "Ifeoluwa", "Oyinkansola", "Ayomide", "Moyinoluwa", "Iretiola", "Damilola",
    "Hadiza", "Hauwa", "Fatima", "Amina", "Maryam", "Nafisa", "Rahma", "Safiya",
    "Asmau", "Bilkisu", "Firdaus", "Hajara", "Khadija", "Salma", "Sumayya", "Ummi",
    "Grace", "Joy", "Peace", "Faith", "Hope", "Mercy", "Patience", "Glory",
    "Esther", "Deborah", "Hannah", "Ruth", "Naomi", "Abigail", "Eunice", "Dorcas",
    "Priscilla", "Lydia", "Comfort", "Precious", "Favour", "Gift", "Happiness",
    "Love", "Wisdom", "Divine", "Princess", "Queen",
]

LAST_NAMES = [
    "Okonkwo", "Adeyemi", "Ibrahim", "Okafor", "Balogun", "Nwosu", "Adebayo", "Eze",
    "Mohammed", "Abubakar", "Nnamdi", "Obi", "Yusuf", "Adeleke", "Chukwu", "Adeola",
    "Musa", "Okeke", "Lawal", "Onuoha", "Ogundimu", "Usman", "Ogundipe", "Olowu",
    "Akinyemi", "Chukwuemeka", "Ojo", "Afolabi", "Nwachukwu", "Aliyu", "Oladipo",
    "Ogunyemi", "Babangida", "Nwafor", "Oyelaran", "Oladele", "Adebiyi", "Uzoma",
    "Okonkwu", "Bello", "Danjuma", "Audu", "Garba", "Sani", "Abdullahi", "Gambo",
    "Shehu", "Tanko", "Waziri", "Dikko", "Ciroma", "Ringim", "Gwarzo", "Hadejia",
    "Aigbe", "Oghene", "Efosa", "Osaze", "Igbinovia", "Osakwe", "Osagie", "Idemudia",
    "Emovon", "Irabor", "Okoh", "Peterside", "Nwokolo", "Anyanwu", "Iheanacho",
    "Obiora", "Achebe", "Adichie", "Ekwueme", "Azikiwe", "Ojukwu", "Ironsi", "Dimka",
    "Babatunde", "Obasanjo", "Awolowo", "Soyinka", "Kuti", "Anikulapo", "Ransome",
    "Solarin", "Awojobi", "Adesanya", "Fashola", "Sanwo-Olu", "Ambode", "Tinubu",
    "Jakande", "Lateef", "Dosunmu", "Ojora", "Elegushi", "Oniru", "Akiolu", "Rilwan",
]

CITIES = [
    "Lagos", "Abuja", "Port Harcourt", "Kano", "Ibadan", "Benin City", "Enugu", "Kaduna",
    "Calabar", "Warri", "Owerri", "Jos", "Abeokuta", "Uyo", "Asaba", "Maiduguri",
    "Ilorin", "Onitsha", "Aba", "Sokoto", "Akure", "Osogbo", "Bauchi", "Lokoja",
    "Yola", "Lafia", "Makurdi", "Minna", "Abakaliki", "Ado-Ekiti",
]

STREET_FORMATS = [
    "{number} {name} Street", "{number} {name} Avenue",
    "{number} {name} Road", "{number} {name} Close",
    "{number} {name} Crescent", "{number} {name} Drive",
]

POSTAL_CODE_FORMAT = "######"
PHONE_FORMAT = "+234 ### ### ####"
CURRENCY = "NGN"
CURRENCY_SYMBOL = "₦"

BANKS = [
    "First Bank of Nigeria", "Zenith Bank", "GTBank", "Access Bank", "UBA",
    "Stanbic IBTC", "Fidelity Bank", "Sterling Bank", "Wema Bank", "Opay",
    "Kuda Bank", "Polaris Bank",
]

EMAIL_DOMAINS = ["gmail.com", "yahoo.com", "hotmail.com", "outlook.com", "protonmail.com", "aol.com"]
COMPANY_SUFFIXES = ["Ltd.", "PLC", "& Sons", "Enterprises", "Nigeria Ltd.", "Group", "& Co."]
COUNTRY_NAME = "Nigeria"
NAME_ORDER = "given_family"
