"""United States locale data — en_US"""

FIRST_NAMES_MALE = [
    "James", "Robert", "Michael", "William", "David", "Richard", "Joseph", "Thomas",
    "Christopher", "Daniel", "Matthew", "Anthony", "Mark", "Steven", "Andrew",
    "Paul", "Joshua", "Kenneth", "Kevin", "Brian", "Timothy", "Ronald", "George",
    "Jason", "Edward", "Jeffrey", "Ryan", "Jacob", "Gary", "Nicholas",
    "Eric", "Jonathan", "Stephen", "Larry", "Justin", "Scott", "Brandon", "Benjamin",
    "Samuel", "Raymond", "Gregory", "Frank", "Alexander", "Patrick", "Jack", "Dennis",
    "Jerry", "Tyler", "Aaron", "Nathan", "Henry", "Peter", "Douglas", "Zachary",
    "Kyle", "Noah", "Harold", "Carl", "Gerald", "Keith", "Logan", "Eugene",
    "Russell", "Randy", "Philip", "Harry", "Vincent", "Bobby", "Dylan", "Johnny",
    "Jesse", "Roy", "Billy", "Bruce", "Gabriel", "Joe", "Jordan", "Ralph",
    "Eugene", "Randy", "Wayne", "Elijah", "Oscar", "Landon", "Caleb", "Mason",
    "Ethan", "Aiden", "Lucas", "Jackson", "Sebastian", "Levi", "Mateo", "Owen",
    "Carter", "Jayden", "Luke", "Hunter", "Wyatt", "Isaac",
]

FIRST_NAMES_FEMALE = [
    "Mary", "Patricia", "Jennifer", "Linda", "Barbara", "Elizabeth", "Susan", "Jessica",
    "Sarah", "Karen", "Lisa", "Nancy", "Betty", "Dorothy", "Sandra", "Ashley",
    "Margaret", "Emily", "Donna", "Michelle", "Carol", "Amanda", "Melissa", "Deborah",
    "Stephanie", "Rebecca", "Sharon", "Laura", "Cynthia", "Kathleen", "Amy", "Angela",
    "Shirley", "Brenda", "Anna", "Pamela", "Emma", "Nicole", "Helen", "Samantha",
    "Katherine", "Christine", "Debra", "Rachel", "Carolyn", "Janet", "Catherine",
    "Maria", "Heather", "Diane", "Ruth", "Julie", "Olivia", "Joyce", "Virginia",
    "Victoria", "Kelly", "Lauren", "Christina", "Joan", "Evelyn", "Judith", "Megan",
    "Andrea", "Cheryl", "Hannah", "Jacqueline", "Martha", "Gloria", "Teresa", "Ann",
    "Sara", "Madison", "Frances", "Kathryn", "Janice", "Jean", "Abigail", "Alice",
    "Julia", "Judy", "Sophia", "Grace", "Denise", "Amber", "Doris", "Marilyn",
    "Danielle", "Beverly", "Isabella", "Theresa", "Diana", "Natalie", "Brittany",
    "Charlotte", "Marie", "Kayla", "Alexis", "Lori",
]

LAST_NAMES = [
    "Smith", "Johnson", "Williams", "Brown", "Jones", "Garcia", "Miller", "Davis",
    "Rodriguez", "Martinez", "Hernandez", "Lopez", "Gonzalez", "Wilson", "Anderson",
    "Thomas", "Taylor", "Moore", "Jackson", "Martin", "Lee", "Perez", "Thompson",
    "White", "Harris", "Sanchez", "Clark", "Ramirez", "Lewis", "Robinson",
    "Walker", "Young", "Allen", "King", "Wright", "Scott", "Torres", "Nguyen",
    "Hill", "Flores", "Green", "Adams", "Nelson", "Baker", "Hall", "Rivera",
    "Campbell", "Mitchell", "Carter", "Roberts", "Gomez", "Phillips", "Evans",
    "Turner", "Diaz", "Parker", "Cruz", "Edwards", "Collins", "Reyes", "Stewart",
    "Morris", "Morales", "Murphy", "Cook", "Rogers", "Gutierrez", "Ortiz", "Morgan",
    "Cooper", "Peterson", "Bailey", "Reed", "Kelly", "Howard", "Ramos", "Kim",
    "Cox", "Ward", "Richardson", "Watson", "Brooks", "Chavez", "Wood", "James",
    "Bennett", "Gray", "Mendoza", "Ruiz", "Hughes", "Price", "Alvarez", "Castillo",
    "Sanders", "Patel", "Myers", "Long", "Ross", "Foster",
]

CITIES = [
    "New York", "Los Angeles", "Chicago", "Houston", "Phoenix", "Philadelphia",
    "San Antonio", "San Diego", "Dallas", "Austin", "San Jose", "Jacksonville",
    "Fort Worth", "Columbus", "Charlotte", "Indianapolis", "San Francisco",
    "Seattle", "Denver", "Nashville", "Oklahoma City", "Portland", "Las Vegas",
    "Memphis", "Louisville", "Baltimore", "Milwaukee", "Albuquerque", "Tucson",
    "Fresno", "Sacramento", "Mesa", "Atlanta", "Omaha", "Raleigh",
]

STREET_FORMATS = [
    "{number} {name} Street", "{number} {name} Avenue",
    "{number} {name} Boulevard", "{number} {name} Drive",
    "{number} {name} Lane", "{number} {name} Way",
    "{number} {name} Court", "{number} {name} Place",
]

POSTAL_CODE_FORMAT = "#####"
PHONE_FORMAT = "+1 (###) ###-####"
CURRENCY = "USD"
CURRENCY_SYMBOL = "$"

BANKS = [
    "JPMorgan Chase", "Bank of America", "Wells Fargo", "Citibank",
    "Goldman Sachs", "US Bank", "PNC Bank", "Capital One",
    "TD Bank", "Truist Financial", "Charles Schwab", "HSBC USA",
]

EMAIL_DOMAINS = ["gmail.com", "yahoo.com", "outlook.com", "icloud.com", "aol.com", "hotmail.com"]
COMPANY_SUFFIXES = ["Inc.", "LLC", "Corp.", "Co.", "Group", "Holdings", "Enterprises"]
COUNTRY_NAME = "United States"
NAME_ORDER = "given_family"
