"""Spain locale data — es_ES"""

FIRST_NAMES_MALE = [
    "Hugo", "Mateo", "Martín", "Lucas", "Leo", "Daniel", "Alejandro", "Pablo", "Manuel",
    "Álvaro", "Adrián", "David", "Mario", "Diego", "Javier", "Carlos", "Miguel", "Sergio",
    "Antonio", "Iker", "Marcos", "Gonzalo", "Iván", "Raúl", "Rubén", "Ángel", "Fernando",
    "Jorge", "Alberto", "Víctor", "Pedro", "Francisco", "José", "Juan", "Rafael", "Andrés",
    "Enrique", "Luis", "Tomás", "Ignacio", "Guillermo", "Nicolás", "Samuel", "Héctor",
    "Emilio", "Ramón", "Arturo", "Salvador", "Eduardo", "Ricardo", "Cristian", "Germán",
    "Félix", "Lorenzo", "Omar", "Bruno", "Darío", "Jaime", "Xavier", "Agustín",
    "Aitor", "Ariel", "Bautista", "Borja", "Claudio", "Damián", "Esteban", "Fabián",
    "Gaspar", "Gregorio", "Hernán", "Ismael", "Joaquín", "Kevin", "Lázaro", "Leandro",
    "Matías", "Néstor", "Orlando", "Patricio", "Rodrigo", "Santiago", "Sebastián", "Simón",
    "Teodoro", "Valentín", "Wenceslao", "Yeray", "Alonso", "Benito", "César", "Domingo",
    "Efrén", "Fidel", "Gerardo", "Hilario", "Julio", "Leonardo", "Mariano", "Pascual",
]

FIRST_NAMES_FEMALE = [
    "Lucía", "Sofía", "Martina", "María", "Julia", "Paula", "Emma", "Daniela", "Valeria",
    "Alba", "Carmen", "Sara", "Noa", "Claudia", "Irene", "Elena", "Laura", "Marta",
    "Laia", "Isabel", "Natalia", "Ana", "Andrea", "Cristina", "Beatriz", "Teresa",
    "Rosa", "Pilar", "Dolores", "Mercedes", "Francisca", "Concepción", "Josefa", "Manuela",
    "Antonia", "Encarnación", "Rosario", "Amparo", "Inmaculada", "Soledad", "Raquel",
    "Silvia", "Patricia", "Verónica", "Mónica", "Nuria", "Alicia", "Eva", "Rocío",
    "Esther", "Lorena", "Miriam", "Sonia", "Susana", "Yolanda", "Montserrat", "Begoña",
    "Virginia", "Carolina", "Adriana", "Inés", "Victoria", "Lidia", "Ángela", "Diana",
    "Olga", "Sandra", "Celia", "Marina", "Blanca", "Noelia", "Ainhoa", "Nerea",
    "Ariadna", "Carlota", "Abril", "Jimena", "Ainara", "Candela", "Carla", "Vera",
    "Leyre", "Olivia", "Aitana", "Alejandra", "Chloe", "Lola", "Luna", "Manuela",
    "Valentina", "Ariana", "Ximena", "Esperanza", "Gloria", "Leonor", "Paloma", "Paz",
    "Remedios", "Consuelo",
]

LAST_NAMES = [
    "García", "Rodríguez", "Martínez", "López", "González", "Hernández", "Pérez", "Sánchez",
    "Ramírez", "Torres", "Flores", "Rivera", "Gómez", "Díaz", "Moreno", "Muñoz", "Álvarez",
    "Romero", "Navarro", "Ruiz", "Jiménez", "Domínguez", "Vázquez", "Ramos", "Gil",
    "Serrano", "Blanco", "Molina", "Suárez", "Ortega", "Delgado", "Castro", "Ortiz",
    "Rubio", "Marín", "Sanz", "Iglesias", "Núñez", "Medina", "Garrido", "Cortés",
    "Castillo", "Santos", "Guerrero", "Lozano", "Cano", "Prieto", "Méndez", "Cruz",
    "Calvo", "Gallego", "Herrera", "Peña", "León", "Márquez", "Cabrera", "Vidal",
    "Lorenzo", "Campos", "Reyes", "Vega", "Fuentes", "Carrasco", "Diez", "Caballero",
    "Nieto", "Aguilar", "Pascual", "Herrero", "Montero", "Giménez", "Hidalgo", "Ibáñez",
    "Soler", "Vargas", "Ferrer", "Arias", "Rojas", "Mora", "Crespo", "Parra",
    "Esteban", "Bravo", "Gallardo", "Duarte", "Benítez", "Moya", "Salas", "Velasco",
    "Palacios", "Rivas", "Santana", "Bermúdez", "Cordero", "Figueroa", "Acosta", "Valencia",
]

CITIES = [
    "Madrid", "Barcelona", "Valencia", "Sevilla", "Zaragoza", "Málaga", "Murcia", "Palma",
    "Bilbao", "Alicante", "Córdoba", "Valladolid", "Granada", "Oviedo", "Salamanca",
    "Vigo", "Gijón", "Vitoria", "La Coruña", "Elche", "Santa Cruz de Tenerife",
    "Las Palmas", "Pamplona", "Almería", "Burgos", "Santander", "Castellón", "Albacete",
    "San Sebastián", "Logroño",
]

STREET_FORMATS = [
    "Calle {name}, {number}", "Avenida de {name}, {number}",
    "Paseo de {name}, {number}", "Plaza de {name}, {number}",
    "Carrera de {name}, {number}", "Camino de {name}, {number}",
]

POSTAL_CODE_FORMAT = "#####"
PHONE_FORMAT = "+34 ### ### ###"
CURRENCY = "EUR"
CURRENCY_SYMBOL = "€"

BANKS = [
    "Santander", "BBVA", "CaixaBank", "Bankinter", "Sabadell", "Unicaja",
    "Kutxabank", "Ibercaja", "Abanca", "Bankia", "Openbank", "ING España",
]

EMAIL_DOMAINS = ["gmail.com", "hotmail.es", "yahoo.es", "outlook.es", "telefonica.net", "terra.es"]
COMPANY_SUFFIXES = ["S.A.", "S.L.", "S.L.U.", "S.Coop.", "& Cía.", "Hermanos"]
COUNTRY_NAME = "España"
NAME_ORDER = "given_family"
