"""Saudi Arabia locale data — ar_SA"""

FIRST_NAMES_MALE = [
    "محمد", "عبدالله", "عبدالعزيز", "فهد", "سلطان", "خالد", "سعود", "نايف", "تركي",
    "بندر", "عبدالرحمن", "سعد", "ماجد", "فيصل", "أحمد", "إبراهيم", "عمر", "علي",
    "ياسر", "طارق", "حسن", "حسين", "يوسف", "صالح", "عادل", "مشاري", "وليد",
    "مساعد", "ناصر", "راشد", "سالم", "زياد", "مازن", "أنس", "بدر", "هاني",
    "عماد", "كريم", "جمال", "منصور", "مروان", "باسل", "رائد", "سامي", "عصام",
    "نواف", "ثامر", "مشعل", "متعب", "عبدالمجيد", "عبدالملك", "عبدالكريم", "عبداللطيف",
    "عبدالإله", "عبدالمحسن", "عبدالهادي", "عبدالواحد", "عبدالرقيب", "عبدالسلام",
    "عبدالقادر", "لؤي", "حمد", "طلال", "هشام", "رامي", "أسامة", "معاذ", "أيمن",
    "شريف", "حاتم", "فواز", "عايض", "صقر", "دخيل", "جابر", "سليمان", "عيسى",
    "موسى", "داود", "نوح", "آدم", "إلياس", "لقمان", "شعيب", "هود", "صلاح",
    "رضوان", "عثمان", "أبوبكر", "زيد", "حمزة", "بلال", "أمجد", "عاصم", "وائل",
    "غسان",
]

FIRST_NAMES_FEMALE = [
    "نورة", "سارة", "لمى", "ريم", "هيفاء", "مها", "أمل", "دلال", "منال", "غادة",
    "فاطمة", "عائشة", "خديجة", "مريم", "زينب", "هند", "أسماء", "سمر", "رنا",
    "لينا", "هدى", "سلوى", "نجلاء", "ابتسام", "نادية", "سميرة", "حنان", "وفاء",
    "صفاء", "رجاء", "بشرى", "زهرة", "ياسمين", "جمانة", "رهف", "لجين", "تالا",
    "دانة", "جوري", "ريناد", "شهد", "وجدان", "حور", "سدين", "غلا", "ميادة",
    "بيان", "أريج", "عبير", "نسرين", "رنيم", "ملاك", "جنى", "سلمى", "يارا",
    "ديمة", "رزان", "هيا", "الجوهرة", "العنود", "لطيفة", "بدور", "شيخة", "موضي",
    "هناء", "إيمان", "آلاء", "روان", "لمياء", "مي", "ندى", "رباب", "سحر",
    "فوزية", "حصة", "منيرة", "جواهر", "أميرة", "شيماء", "مرام", "بسمة", "نجوى",
    "علياء", "خلود", "لولوة", "مشاعل", "عزيزة", "ريحانة", "سندس", "إسراء", "كوثر",
    "رقية", "سكينة", "فريدة", "حبيبة", "تهاني", "ليلى", "عفاف", "نعيمة", "راوية",
]

LAST_NAMES = [
    "القحطاني", "العتيبي", "الغامدي", "الدوسري", "الشهري", "الحربي", "الزهراني",
    "المطيري", "الشمري", "العنزي", "السبيعي", "المالكي", "الأحمدي", "البلوي",
    "الرشيدي", "الجهني", "الحارثي", "السلمي", "الثبيتي", "البقمي", "العمري",
    "الصاعدي", "الشريف", "الهاشمي", "الحسيني", "العلوي", "الزيدي", "المحمدي",
    "الخالدي", "السعدي", "الناصري", "الفهدي", "التميمي", "القرشي", "المكي",
    "المدني", "الأنصاري", "العمراني", "الشيباني", "الكندي", "الراجحي", "الدخيل",
    "الشويعر", "النمر", "البراك", "الفوزان", "السويلم", "المنيف", "الحقباني",
    "العسيري", "الخثعمي", "الوادعي", "النخلي", "الغزالي", "العسكري", "الرومي",
    "الفارسي", "الهندي", "التركي", "اليماني", "المصري", "الشامي", "العراقي",
    "الحجازي", "النجدي", "القصيمي", "الحساوي", "الدمشقي", "البغدادي", "الموصلي",
    "السديري", "الثنيان", "الجفالي", "العليان", "الراشد", "المحيسن", "الطريقي",
    "البكري", "الماضي", "النويصر", "الحمدان", "السيف", "الرميح", "الحبيب",
    "العقيل", "الشثري", "المنقور", "اللحيدان", "العيسى", "البسام", "المقبل",
    "الزامل", "القاسم", "الربيعة", "السالم", "العبيد", "الصقر", "الحميد", "النفيسة",
]

CITIES = [
    "الرياض", "جدة", "مكة", "المدينة", "الدمام", "الخبر", "تبوك", "أبها", "الطائف",
    "بريدة", "خميس مشيط", "حائل", "نجران", "جازان", "ينبع", "القطيف", "الجبيل",
    "الظهران", "عرعر", "سكاكا", "الباحة", "بيشة", "الخرج", "عنيزة", "الرس",
]

STREET_FORMATS = [
    "شارع {name}، حي {district}، {number}",
    "طريق {name}، {number}",
]

POSTAL_CODE_FORMAT = "#####"
PHONE_FORMAT = "+966 ## ### ####"
CURRENCY = "SAR"
CURRENCY_SYMBOL = "﷼"

BANKS = [
    "البنك الأهلي السعودي", "بنك الراجحي", "بنك الرياض", "البنك السعودي البريطاني",
    "بنك الجزيرة", "البنك السعودي الفرنسي", "بنك البلاد", "بنك الإنماء",
    "البنك العربي الوطني", "بنك الاستثمار السعودي", "بنك السعودي الهولندي",
    "مصرف الراجحي",
]

EMAIL_DOMAINS = ["gmail.com", "hotmail.com", "outlook.sa", "yahoo.com", "outlook.com", "stc.com.sa"]
COMPANY_SUFFIXES = ["ش.م.", "ش.ذ.م.م", "مؤسسة", "شركة", "مجموعة"]
COUNTRY_NAME = "المملكة العربية السعودية"
NAME_ORDER = "given_family"
