"""Germany locale data — de_DE"""

FIRST_NAMES_MALE = [
    "Lukas", "Leon", "Finn", "Elias", "Jonas", "Ben", "Noah", "Paul", "Maximilian", "Felix",
    "Alexander", "Moritz", "Tim", "Julian", "Erik", "Niklas", "Luca", "Jan", "Sebastian",
    "Tobias", "David", "Florian", "Marcel", "Dennis", "Christian", "Philipp", "Patrick",
    "Stefan", "Martin", "Thomas", "Andreas", "Markus", "Oliver", "Daniel", "Matthias",
    "Frank", "Peter", "Klaus", "Hans", "Werner", "Heinz", "Karl", "Friedrich", "Heinrich",
    "Gerhard", "Wolfgang", "Manfred", "Jürgen", "Günter", "Dieter", "Rainer", "Bernd",
    "Uwe", "Ralf", "Holger", "Torsten", "Sven", "Kai", "Dirk", "Ingo", "Lars", "Jens",
    "Marc", "Christoph", "Simon", "Jakob", "Emil", "Oskar", "Theo", "Anton", "Leo", "Mats",
    "Lennart", "Hannes", "Jannik", "Timo", "Nico", "Robin", "Fabian", "Dominik", "Kevin",
    "Mario", "Manuel", "Robert", "Sascha", "Hendrik", "Bastian", "Thorsten", "Volker",
    "Norbert", "Helmut", "Lothar", "Siegfried", "Rudolf", "Erich", "Otto", "Fritz",
    "Gustav", "Albert", "Walter", "Georg", "Hermann",
]

FIRST_NAMES_FEMALE = [
    "Emma", "Mia", "Hannah", "Sophia", "Lina", "Marie", "Lea", "Clara", "Anna", "Emilia",
    "Laura", "Johanna", "Lena", "Charlotte", "Amelie", "Luisa", "Sophie", "Leonie", "Nele",
    "Ella", "Ida", "Frieda", "Mila", "Greta", "Maja", "Julia", "Lisa", "Sarah", "Katharina",
    "Franziska", "Lara", "Jana", "Vanessa", "Nicole", "Sabine", "Andrea", "Claudia",
    "Stefanie", "Sandra", "Birgit", "Monika", "Petra", "Heike", "Karin", "Ursula", "Helga",
    "Ingrid", "Renate", "Christa", "Gertrud", "Elfriede", "Irmgard", "Edith", "Hildegard",
    "Brigitte", "Gisela", "Elisabeth", "Ilse", "Erika", "Marianne", "Anneliese", "Waltraud",
    "Hannelore", "Margarete", "Ruth", "Annika", "Antonia", "Pauline", "Victoria", "Helena",
    "Theresa", "Carolin", "Melanie", "Nadine", "Tanja", "Anja", "Diana", "Silke", "Daniela",
    "Katrin", "Susanne", "Marion", "Martina", "Bettina", "Sonja", "Yvonne", "Simone",
    "Angelika", "Gabriele", "Christine", "Barbara", "Eva", "Maria", "Rosemarie", "Lieselotte",
    "Annette", "Beate", "Cornelia", "Doris", "Elke",
]

LAST_NAMES = [
    "Müller", "Schmidt", "Schneider", "Fischer", "Weber", "Meyer", "Wagner", "Becker",
    "Schulz", "Hoffmann", "Koch", "Richter", "Wolf", "Schröder", "Neumann", "Schwarz",
    "Zimmermann", "Braun", "Krüger", "Hofmann", "Hartmann", "Lange", "Schmitt", "Werner",
    "Schmitz", "Krause", "Meier", "Lehmann", "Schmid", "Schulze", "Maier", "Köhler",
    "Herrmann", "König", "Walter", "Mayer", "Huber", "Kaiser", "Fuchs", "Peters",
    "Lang", "Scholz", "Möller", "Weiß", "Jung", "Hahn", "Schubert", "Vogel", "Friedrich",
    "Keller", "Günther", "Frank", "Berger", "Winkler", "Roth", "Beck", "Lorenz", "Baumann",
    "Franke", "Albrecht", "Schuster", "Simon", "Ludwig", "Böhm", "Winter", "Kraus", "Martin",
    "Schumacher", "Krämer", "Vogt", "Stein", "Jäger", "Otto", "Sommer", "Groß", "Seidel",
    "Heinrich", "Brandt", "Haas", "Schreiber", "Graf", "Schultz", "Dietrich", "Ziegler",
    "Kuhn", "Kühn", "Pohl", "Engel", "Horn", "Busch", "Bergmann", "Thomas", "Voigt",
    "Sauer", "Arnold", "Wolff", "Pfeiffer", "Brinkmann", "Kraft", "Marx", "Ritter", "Stark",
]

CITIES = [
    "Berlin", "Hamburg", "München", "Köln", "Frankfurt", "Stuttgart", "Düsseldorf", "Leipzig",
    "Dortmund", "Essen", "Bremen", "Dresden", "Hannover", "Nürnberg", "Duisburg", "Bochum",
    "Wuppertal", "Bielefeld", "Bonn", "Münster", "Mannheim", "Karlsruhe", "Augsburg",
    "Wiesbaden", "Mönchengladbach", "Gelsenkirchen", "Aachen", "Braunschweig", "Kiel",
    "Chemnitz", "Halle", "Magdeburg", "Freiburg", "Lübeck", "Erfurt",
]

STREET_FORMATS = [
    "{name}straße {number}", "{name}weg {number}", "{name}allee {number}",
    "{name}platz {number}", "{name}ring {number}", "{name}damm {number}",
]

POSTAL_CODE_FORMAT = "#####"
PHONE_FORMAT = "+49 ### #######"
CURRENCY = "EUR"
CURRENCY_SYMBOL = "€"

BANKS = [
    "Deutsche Bank", "Commerzbank", "DZ Bank", "KfW", "Sparkasse", "Volksbank",
    "Postbank", "HypoVereinsbank", "ING-DiBa", "Targobank", "Landesbank", "N26",
]

EMAIL_DOMAINS = ["gmail.com", "web.de", "gmx.de", "t-online.de", "outlook.de", "freenet.de"]
COMPANY_SUFFIXES = ["GmbH", "AG", "e.V.", "KG", "OHG", "SE", "GmbH & Co. KG"]
COUNTRY_NAME = "Deutschland"
NAME_ORDER = "given_family"
